*******
Scripts
*******

There are a number of scripts for each platform that perform simple tasks
without having to write specifications.




vSphere Scripts
===============

.. automodule:: adles.vsphere.vsphere_scripts

.. automodule:: adles.scripts.script_base
